==> tts_curl_V3.0_2010-05-25_1.tar.gz: tts_curl_V3.0_2010-05-25_1/www/config.php <==
<?
#Active CDR statistics :
$enable_record_to_cdr=false;


#Common Languages en variantes
#http://www.w3.org/International/articles/language-tags/
#
# language-Script-REGION-variant-extension-privateuse
#
#The entries in the registry follow certain conventions with regard to upper and 
#lowercasing - for example, language tags are lower case, alphabetic region subtags
#are upper case, and script tags begin with an initial capital. This is only a 
#convention! When you use these subtags you are free to do as you like.


#default tts engine is the first in this tts array :
$tts=array();

#curl_begin

#Limited at 100 chars / call
$tts['google']= array(
      "name" => "google",
      "call"  => "ttsgoogle",
      "options" => array('"http://translate.google.com/translate_tts"','$text', '$lang','$filename'),
      "voices"=>array(
                      '1'  => array(
                          'type'=>'male',
                          'desc'=>'Default Voice',
                          'voptions' => array ()
                       ),
             ),
      "langcodes" => array(
                         'en' => array('1'),
                         'fr' => array('1'),
                         'es' => array('1'),
                         'it' => array('1'),
                         'pt' => array('1'),
                         'de' => array('1'),
                         'ca' => array('1'),
                          ),
      "charsets" => array('UTF-8'),
      #internal codecs and formats  
      "codecs" => array('pcm'=>'pcm'),
      "iformats" => array('raw'),
      #which internal codecs and formats must be used to get good VXI formats
      "vxiformats" => array('raw' => array('iformat'=>'raw','codec'=>'pcm')),
      "formatiscodec"=>false,
      "createlistfile"=>false,
      "directphpfunction"=>true,
      "debugargs"=>"",
      "checks"=>array("ttsgoogle","curl_setopt","/usr/local/bin/ffmpeg"),
    );

$tts['url']= array(
      "name" => "url",
      "call"  => "ttsurl",
      "options" => array('"http://any.url.com"','$text', '$voice'),
      "voices"=>array(
                      '2'  => array(
                          'type'=>'male',
                          'desc'=>'Greek Male',
                          'voptions' => array ('vparam' => 'VAlUE')
                       ),
             ),
      "langcodes" => array(
                         'el' => array('2'),
                          ),
      "charsets" => array('UTF-8'),
      #internal codecs and formats  
      "codecs" => array('ulaw'=>'ulaw'),
      "iformats" => array('raw'),
      #which internal codecs and formats must be used to get good VXI formats
      "vxiformats" => array('raw' => array('iformat'=>'raw','codec'=>'ulaw')),
      "formatiscodec"=>false,
      "createlistfile"=>false,
      "directphpfunction"=>true,
      "debugargs"=>"",
      "checks"=>array("ttsurl","curl_setopt","/usr/local/bin/ffmpeg"),
    );

#curl_end




# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:

==> tts_curl_V4.0_2010-12-02_5.tar.gz: tts_curl_V4.0_2010-12-02_5/www/config.php <==
<?
#Active CDR statistics :
$enable_record_to_cdr=false;


#Common Languages en variantes
#http://www.w3.org/International/articles/language-tags/
#
# language-Script-REGION-variant-extension-privateuse
#
#The entries in the registry follow certain conventions with regard to upper and 
#lowercasing - for example, language tags are lower case, alphabetic region subtags
#are upper case, and script tags begin with an initial capital. This is only a 
#convention! When you use these subtags you are free to do as you like.


#default tts engine is the first in this tts array :
$tts=array();

#curl_begin

#Limited at 100 chars / call
$tts['google']= array(
      "name" => "google",
      "call"  => "ttsgoogle",
      "options" => array('"http://translate.google.com/translate_tts"','$text', '$lang','$filename'),
      "voices"=>array(
                      '1'  => array(
                          'type'=>'male',
                          'desc'=>'Default Voice',
                          'voptions' => array ()
                       ),
             ),
      "langcodes" => array(
                         'en' => array('1'),
                         'fr' => array('1'),
                         'es' => array('1'),
                         'it' => array('1'),
                         'pt' => array('1'),
                         'de' => array('1'),
                         'ca' => array('1'),
                          ),
      "charsets" => array('UTF-8'),
      #internal codecs and formats  
      "codecs" => array('pcm'=>'pcm'),
      "iformats" => array('raw'),
      #which internal codecs and formats must be used to get good VXI formats
      "vxiformats" => array('raw' => array('iformat'=>'raw','codec'=>'pcm')),
      "formatiscodec"=>false,
      "createlistfile"=>false,
      "directphpfunction"=>true,
      "debugargs"=>"",
      "checks"=>array("ttsgoogle","curl_setopt","/usr/local/bin/ffmpeg"),
    );

$tts['url']= array(
      "name" => "url",
      "call"  => "ttsurl",
      "options" => array('"http://dev.realize.gr/innottsreader/default.aspx"','$text', '$voiceid','$rate','$pitch'),
      "voices"=>array(
                      'voice2'  => array(
                          'type'=>'male',
                          'desc'=>'Greek Female',
                          'voptions' => array ('voiceid' => '2','rate'=>'0','pitch'=>'0')
                       ),
                      'voice2bis'  => array(
                          'type'=>'male',
                          'desc'=>'Greek Female tunned',
                          'voptions' => array ('voiceid' => '2','rate'=>'50','pitch'=>'-50')
                       ),
             ),
      "langcodes" => array(
                         'el' => array('voice2','voice2bis'),
                          ),
      "charsets" => array('UTF-8'),
      #internal codecs and formats  
      "codecs" => array('ulaw'=>'ulaw'),
      "iformats" => array('raw'),
      #which internal codecs and formats must be used to get good VXI formats
      "vxiformats" => array('raw' => array('iformat'=>'raw','codec'=>'ulaw')),
      "formatiscodec"=>false,
      "createlistfile"=>false,
      "directphpfunction"=>true,
      "debugargs"=>"",
      "checks"=>array("ttsurl","curl_setopt","/usr/local/bin/ffmpeg"),
    );

#curl_end




# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:
